@@ -28,11 +28,11 @@
  * This file contains the memory management subsystem.
  *
  * @author Michael Jennings <mej@eterm.org>
- * $Revision: 1.24 $
- * $Date: 2004/07/23 21:38:39 $
+ * $Revision: 1.25 $
+ * $Date: 2005/12/22 23:28:55 $
  */
 
-static const char __attribute__((unused)) cvs_ident[] = "$Id: mem.c,v 1.24 2004/07/23 21:38:39 mej Exp $";
+static const char __attribute__((unused)) cvs_ident[] = "$Id: mem.c,v 1.25 2005/12/22 23:28:55 mej Exp $";
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -645,9 +645,8 @@ spifmem_x_create_pixmap(const spif_charptr_t filename, unsigned long line, Displ
 {
     Pixmap p;
 
-    D_MEM(("Creating %ux%u pixmap of depth %u for window 0x%08x at %s:%lu\n", w, h, depth, win, NONULL(filename), line));
-
     p = XCreatePixmap(d, win, w, h, depth);
+    D_MEM(("Created %ux%u pixmap 0x%08x of depth %u for window 0x%08x at %s:%lu\n", w, h, p, depth, win, NONULL(filename), line));
     ASSERT_RVAL(p != None, None);
     if (DEBUG_LEVEL >= DEBUG_MEM) {
         memrec_add_var(&pixmap_rec, SPIF_CAST(charptr) NONULL(filename), line, (void *) p, w * h * (depth / 8));
